jQuery showLoading example

Show default loading indicator
Hide default loading indicator
simulate 1-second Ajax load
show 'bars'-style loading indicator
Hide 'bars'-style indicator
Usage with jQuery load method:

    jQuery('#activity_pane').showLoading();
    jQuery('#activity_pane').load(
        '/path/to/my/url',
        {},
        function() {
          //
          //this is the ajax callback
          //
          jQuery('#activity_pane').hideLoading();
        }
    );

Here is where we will load something via ajax.
This container must have an id attribute